<?php
declare(strict_types=1);
/**
 * @copyright Copyright (c) 2019, Roeland Jago Douma <roeland@famdouma.nl>
 *
 * @author Roeland Jago Douma <roeland@famdouma.nl>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

namespace OCA\Files_Sharing\Listener;

use OCP\EventDispatcher\Event;
use OCP\EventDispatcher\IEventListener;
use OCP\IConfig;
use OCP\Share\Events\SharedEvent;
use OCP\Share\IManager;

class UserShareAcceptanceListener implements IEventListener {

	/** @var IConfig */
	private $config;
	/** @var IManager */
	private $shareManager;
	/** @var string */
	private $userId;

	public function __construct(IConfig $config, IManager $shareManager, string $userId) {
		$this->config = $config;
		$this->shareManager = $shareManager;
		$this->userId = $userId;
	}

	public function handle(Event $event): void {
		if (!($event instanceof SharedEvent)) {
			return;
		}

		if ($this->config->getUserValue($this->userId, 'files_sharing','default_accept','no') === 'yes') {
			$share = $event->getShare();
			$this->shareManager->acceptShare($share, $this->userId);
		}
	}

}
